@@ -1,6 +1,8 @@
 // Copyright 2021-2022 IOTA Stiftung
 // SPDX-License-Identifier: Apache-2.0
 
+use core::convert::Infallible;
+
 use crate::{
     error::{UnpackError, UnpackErrorExt},
     packer::Packer,
@@ -8,21 +10,20 @@ use crate::{
     Packable,
 };
 
-use core::convert::Infallible;
-
 impl Packable for bool {
     type UnpackError = Infallible;
 
     /// Booleans are packed as `u8` integers following Rust's data layout.
-    #[inline(always)]
+    #[inline]
     fn pack<P: Packer>(&self, packer: &mut P) -> Result<(), P::Error> {
         (*self as u8).pack(packer)
     }
 
     /// Booleans are unpacked if the byte used to represent them is non-zero.
+    #[inline]
     fn unpack<U: Unpacker, const VERIFY: bool>(
         unpacker: &mut U,
     ) -> Result<Self, UnpackError<Self::UnpackError, U::Error>> {
-        Ok(u8::unpack::<_, VERIFY>(unpacker).infallible()? != 0)
+        Ok(u8::unpack::<_, VERIFY>(unpacker).coerce()? != 0)
     }
 }
