@@ -9,7 +9,7 @@ pub(crate) struct LenPacker(pub(crate) usize);
 impl Packer for LenPacker {
     type Error = core::convert::Infallible;
 
-    #[inline(always)]
+    #[inline]
     fn pack_bytes<B: AsRef<[u8]>>(&mut self, bytes: B) -> Result<(), Self::Error> {
         self.0 += bytes.as_ref().len();
 
